# Astral

This is 'astral' a Python module which calculates

- Times for various positions of the sun: dawn, sunrise, solar noon,
sunset, dusk, solar elevation, solar azimuth and rahukaalam.
- The phase of the moon.

For documentation see the <https://astral.readthedocs.io/en/latest/index.html>

## Package Status

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/sffjunkie/astral/astral-test) ![PyPI - Downloads](https://img.shields.io/pypi/dm/astral)
